package com.fs.app.service.impl;

import com.alibaba.fastjson.JSON;
import com.fs.app.param.ChangeUserDeptAndPostParam;
import com.fs.app.service.IAppService;
import com.fs.app.vo.CompanyRoleVO;
import com.fs.app.vo.UserPostVO;
import com.fs.common.exception.CustomException;
import com.fs.common.utils.StringUtils;
import com.fs.company.domain.*;
import com.fs.company.service.*;
import lombok.AllArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.Arrays;
import java.util.List;
import java.util.Objects;
import java.util.Set;
import java.util.stream.Collectors;

@Service
@Slf4j
@AllArgsConstructor
public class AppServiceImpl implements IAppService {

    private final ICompanyUserService companyUserService;
    private final ICompanyDeptService companyDeptService;
    private final ICompanyPostService companyPostService;
    private final ICompanyUserPostService companyUserPostService;
    private final ICompanyRoleService companyRoleService;
    private final ICompanyUserRoleService companyUserRoleService;


    @Override
    public void changeUserDeptAndPost(ChangeUserDeptAndPostParam param) {

    }

    /**
     * 获取公司部门树
     * @param companyId 公司ID
     * @return  list
     */
    @Override
    public List<CompanyDeptTreeSelect> getDeptTreeSelect(Long companyId) {
        log.debug("getDeptTreeSelect companyId: {}", companyId);
        if (Objects.isNull(companyId)) {
            throw new CustomException("获取companyId失败, 请重新登录");
        }
        CompanyDept dept = new CompanyDept();
        dept.setCompanyId(companyId);
        dept.setStatus("0");
        List<CompanyDept> depts = companyDeptService.selectCompanyDeptList(dept);
        return companyDeptService.buildDeptTreeSelect(depts);
    }

    /**
     * 获取公司岗位列表
     * @param companyId 公司ID
     * @return list
     */
    @Override
    public List<UserPostVO> postList(Long companyId) {
        log.debug("postList companyId: {}", companyId);
        if (Objects.isNull(companyId)) {
            throw new CustomException("获取companyId失败, 请重新登录");
        }
        CompanyPost companyPost = new CompanyPost();
        companyPost.setCompanyId(companyId);
        return companyPostService.selectCompanyPostList(companyPost).stream().map(p -> {
            UserPostVO userPostVO = new UserPostVO();
            userPostVO.setPostId(p.getPostId());
            userPostVO.setPostName(p.getPostName());
            return userPostVO;
        }).collect(Collectors.toList());
    }

    /**
     * 获取公司角色列表
     * @param companyId 公司ID
     * @return  list
     */
    @Override
    public List<CompanyRoleVO> roleList(Long companyId) {
        log.debug("roleList companyId: {}", companyId);
        if (Objects.isNull(companyId)) {
            throw new CustomException("获取companyId失败, 请重新登录");
        }
        CompanyRole companyRole = new CompanyRole();
        companyRole.setCompanyId(companyId);
        companyRole.setStatus("0");
        companyRole.setDelFlag("0");
        return companyRoleService.selectCompanyRoleList(companyRole).stream().map(r -> {
            CompanyRoleVO companyRoleVO = new CompanyRoleVO();
            companyRoleVO.setRoleId(r.getRoleId());
            companyRoleVO.setRoleName(r.getRoleName());
            return companyRoleVO;
        }).collect(Collectors.toList());
    }
}
